@@ -17,10 +17,14 @@ def load() -> dict:
 
 
 def write(data: dict) -> None:
+    origin = load()
     with open(path, 'w+') as f:
-        origin = yaml.load(''.join(f.readlines()))
         if origin:
             yaml_data = dict(origin, **data)
         else:
             yaml_data = dict({'build': [str(time.time())]}, **data)
         f.write(yaml.dump(yaml_data))
+
+
+def has_venv():
+    return exist() and os.path.exists('.env')
