@@ -184,7 +184,12 @@ def doc(args):
     return os.system('sphinx-apidoc ./ -o ./docs -F')
 
 
-def git_serve(args):
+@as_command
+def serve(args):
+    '''
+    @argument --ip, help=IP addr
+    @argument --port, help=Port
+    '''
     port = args.port or '30976'
     ip = args.ip or '0.0.0.0'
     print('git daemon will listen on %s:%s/.git' % (ip, port))
@@ -210,7 +215,7 @@ def router(argv) -> Callable:
         'uninstall': uninstall,
         'install': install,
         'pass': uninstall,
-        'serve': git_serve,
+        'serve': serve,
         'coverage': coverage,
         'doc': doc,
         'fab': fab
